@@ -2,26 +2,27 @@ import logging
 
 import backtrader as bt
 
-from koapy.backtrader.KiwoomOpenApiStore import KiwoomOpenApiStore
-from koapy.backtrader.KiwoomOpenApiBroker import KiwoomOpenApiCommInfo
+from koapy.backtrader.KiwoomOpenApiPlusStore import KiwoomOpenApiPlusStore
+from koapy.backtrader.KiwoomOpenApiPlusBroker import KiwoomOpenApiPlusCommInfo
 
 from koapy.backtrader.examples.vanila_quickstart import OrclStrategy
 
 def main():
     cerebro = bt.Cerebro() # pylint: disable=unexpected-keyword-arg
 
-    kiwoomstore = KiwoomOpenApiStore()
+    kiwoomstore = KiwoomOpenApiPlusStore()
 
-    data = kiwoomstore.getdata(dataname='005930', historical=False)
-    cerebro.adddata(data)
+    historial_data = kiwoomstore.getdata(dataname='005930', historical=True)
+    realtime_data = kiwoomstore.getdata(dataname='005930', backfill_start=False, timeframe=bt.TimeFrame.Ticks, compression=1)
+
+    cerebro.adddata(historial_data)
 
     cerebro.addsizer(bt.sizers.FixedSize, stake=10)
     cerebro.addtz('Asia/Seoul')
 
     cerebro.broker.setcash(30000000.0)
-    cerebro.broker.addcommissioninfo(KiwoomOpenApiCommInfo())
+    cerebro.broker.addcommissioninfo(KiwoomOpenApiPlusCommInfo())
 
-    # _strats = cerebro.optstrategy(OrclStrategy, maperiod=range(10, 31))
     cerebro.addstrategy(OrclStrategy, printlog=True)
 
     logging.info('Starting Portfolio Value: %.2f', cerebro.broker.getvalue())
